==> kdesvn-0.9.2.tar.bz2: kdesvn-0.9.2/src/settings/cmdexecsettings_impl.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Rajko Albrecht                                  *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef CMDEXECSETTINGS_IMPL_H
#define CMDEXECSETTINGS_IMPL_H

#include "src/settings/cmdexecsettings.h"

class CmdExecSettings_impl : public CmdExecSettings
{
  Q_OBJECT

public:
  CmdExecSettings_impl(QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
  ~CmdExecSettings_impl();
  /*$PUBLIC_FUNCTIONS$*/

public slots:
  /*$PUBLIC_SLOTS$*/

protected:
  /*$PROTECTED_FUNCTIONS$*/
    void showLogToggled(bool);

protected slots:
  /*$PROTECTED_SLOTS$*/

};

#endif

==> kdesvn_1.5.5.orig.tar.bz2: kdesvn-1.5.5/src/settings/cmdexecsettings_impl.h <==
/***************************************************************************
 *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef CMDEXECSETTINGS_IMPL_H
#define CMDEXECSETTINGS_IMPL_H

#include "src/settings/ui_cmdexecsettings.h"

class CmdExecSettings_impl : public QWidget, public Ui::CmdExecSettings
{
  Q_OBJECT

public:
  CmdExecSettings_impl(QWidget* parent = 0);
  ~CmdExecSettings_impl();
  /*$PUBLIC_FUNCTIONS$*/

public slots:
  /*$PUBLIC_SLOTS$*/

protected:

protected slots:
  /*$PROTECTED_SLOTS$*/

};

#endif
